==> pymuco-1.0.0.tar.gz: pymuco-1.0.0/README.md <==
<h1 align="center">
<img src="https://raw.githubusercontent.com/pymuco/pymuco/main/docs/_static/pymucologo.png" width="50%">
</h1>

<p align="center">
  <a href="https://github.com/pymuco/pymuco/actions/workflows/python-app.yml">
    <img src="https://github.com/pymuco/pymuco/actions/workflows/python-app.yml/badge.svg" alt="CI" style="background-color:#2E6AFF; color:black;">
  </a>
  <a href="https://pymuco.readthedocs.io/en/latest/?badge=latest">
    <img src="https://readthedocs.org/projects/pymuco/badge/?version=latest" alt="Documentation Status" style="background-color:#2E6AFF; color:black;">
  </a>
  <img src="https://img.shields.io/pypi/dm/pymuco?color=brightgreen&label=PyPi" alt="PyPI" style="background-color:#2E6AFF; color:black;">
  <a href="https://pymuco.org">
    <img src="https://img.shields.io/badge/status-1.0.0-brightgreen" alt="Status" style="background-color:#2E6AFF; color:black;">
  </a>
  <a href="https://opensource.org/">
    <img src="https://img.shields.io/badge/Open%20Source-%3CCOLOR%3E?style=flat&labelColor=%3CCOLOR%3E&color=%3CCOLOR%3E&logo=open-source-initiative&logoColor=white" alt="Open Source" style="background-color:#2E6AFF; color:black;">
  </a>
</p>

Pymuco: A Python Music Computation Library for Musicians and Developers

Purely Pythonic 🐍 Zero dependencies

- **Website:** https://pymuco.org
- **PyPi:** https://pypi.org/project/pymuco/
- **Source code:** https://github.com/pymuco/pymuco
- **Documentation:** https://pymuco.readthedocs.io/en/latest/
- **Issue tracker:** https://github.com/pymuco/pymuco/issues 
- **Community** https://github.com/orgs/pymuco/discussions
- **Report a security vulnerability:** https://github.com/pymuco/pymuco/security/policy

Getting Started
---------------

```pip install pymuco```

Features
--------

Pymuco library offers a comprehensive toolkit that includes:

- Integration of theoretical musical concepts
- Development of an autonomous notation system for computer music
- Conversion of musical code to executable audio file
- Utilities related to MIDI

Testing
-------

To run tests for Pymuco, you can use Python's built-in `unittest` module. Simply execute the following command:

```python3 -m unittest discover test```

Contributions
---------------

Contributions to Pymuco are encouraged and can be made by forking the repository, making changes, testing, and submitting a pull request. Detailed instructions on how to contribute can be found in the [How to contribute](https://github.com/pymuco/pymuco/tree/main/docs/CONTRIBUTIONS.md) guide.


Code of Conduct
---------------

Pymuco follows the Contributor Covenant Code of Conduct, which sets the standards for behavior and aims to create a welcoming and inclusive community. For more information, please refer to the [Contributor Covenant Code of Conduct](https://github.com/pymuco/pymuco/blob/main/CODE_OF_CONDUCT.md) file.


Copyright and License Information
---------------------------------

Copyright © 2022-2023 German Margon. All rights reserved.

See the [LICENSE](LICENSE) for information, terms & conditions for usage, and a DISCLAIMER OF ALL WARRANTIES.

All trademarks referenced herein are property of their respective holders.

==> pymuco-1.1b6.tar.gz: pymuco-1.1b6/README.md <==
<h1 align="center">
<img src="https://raw.githubusercontent.com/pymuco/pymuco/main/docs/_static/pymucologo.png" width="150%">
</h1>

[![CI](https://github.com/pymuco/pymuco/actions/workflows/python-app.yml/badge.svg)](https://github.com/pymuco/pymuco/actions/workflows/python-app.yml)
![PyPI Downloads](https://img.shields.io/pypi/dm/pymuco?color=%2345aaf5&label=PyPi%20Downloads)
![Status](https://img.shields.io/pypi/status/pymuco?color=%2345aaf5)



Pymuco is an open source Python library designed for music programming.  

Purely Pythonic 🐍 Zero dependencies

- **Website:** https://www.pymuco.org
- **PyPi:** https://pypi.org/project/pymuco/
- **Source code:** https://github.com/pymuco/pymuco
- **Documentation:** https://pymuco.org/doc (WIP)
- **Bug reports:** https://github.com/pymuco/pymuco/issues 
- **Discussions** https://github.com/orgs/pymuco/discussions

Getting Started
---------------

```pip install pymuco```

Features
--------

Pymuco library offers a comprehensive toolkit that includes:

- Integration of theoretical musical concepts
- Development of an autonomous notation system for computer music
- Conversion of musical code to executable audio file
- Utilities related to MIDI

Testing
-------

To run tests for Pymuco, you can use Python's built-in `unittest` module. Simply execute the following command:

```python3 -m unittest discover test```

Contributions
---------------

Contributions to Pymuco are encouraged and can be made by forking the repository, making changes, testing, and submitting a pull request. Detailed instructions on how to contribute can be found in the [How to contribute](https://github.com/pymuco/pymuco/tree/main/docs/CONTRIBUTIONS.md) guide.


Code of Conduct
---------------

Pymuco follows the Contributor Covenant Code of Conduct, which sets the standards for behavior and aims to create a welcoming and inclusive community. For more information, please refer to the [Contributor Covenant Code of Conduct](https://github.com/pymuco/pymuco/blob/main/CODE_OF_CONDUCT.md) file.


Copyright and License Information
---------------------------------

Copyright © 2022-2023 German Margon. All rights reserved.

See the [LICENSE](LICENSE) for information, terms & conditions for usage, and a DISCLAIMER OF ALL WARRANTIES.

All trademarks referenced herein are property of their respective holders.
